﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Caliburn.Micro;
using System.Windows.Data;
using System.Windows.Controls;
using System.Windows;
using RibbonApplication.Models;
using static RibbonApplication.Models.Ribbon;


namespace RibbonApplication.Converters
{
   class RibbonConverters : IValueConverter
   {
      public object Convert(object value, Type targetType, object parameter,
      System.Globalization.CultureInfo culture)
      {
         if (value.Equals(true))
         {
            return "Large";
         }
         else
         {
            return "Small";
         }
      }
      public object ConvertBack(object value, Type targetType, object parameter,
      System.Globalization.CultureInfo culture)
      {
         throw new NotImplementedException();
      }
   }
   public class ItemDataTemplateSelector : DataTemplateSelector
   {
      public override DataTemplate SelectTemplate(object item, DependencyObject container)
      {
         FrameworkElement element = container as FrameworkElement;
         if (element != null && item != null)
         {
            if (item is CustomRibbonItem && (item as CustomRibbonItem).IsSplitButton.Equals("Splitbutton"))
            {
               return element.FindResource("Splitbutton") as DataTemplate;
            }
            else if (item is CustomRibbonItem && (item as CustomRibbonItem).IsSplitButton.Equals("separator"))
            {
               return element.FindResource("Separator") as DataTemplate;
            }
            else if (item is CustomRibbonItem && (item as CustomRibbonItem).IsSplitButton.Equals("Checkbox"))
            {
               return element.FindResource("Checkbox") as DataTemplate;
            }

            else
            {
               return element.FindResource("Ribbonbutton") as DataTemplate;
            }
         }
         return null;
      }
   }


   public class DropDownConverter : DataTemplateSelector
   {
      public override DataTemplate SelectTemplate(object item, DependencyObject container)
      {
         FrameworkElement element = container as FrameworkElement;
         if (element != null && item != null)
         {
            if (item is CustomRibbonDropDown)
            {
               return element.FindResource("combo") as DataTemplate;
            }

         }
         return null;
      }
   }


   public class ImageConverter : IValueConverter
   {
      public object Convert(object value, Type targetType, object parameter,
      System.Globalization.CultureInfo culture)
      {
         if (value != null)
         {
            string str = value.ToString();
            return "../Images/" + str;
         }
         else
         {
            return value;
         }
      }
      public object ConvertBack(object value, Type targetType, object parameter,
      System.Globalization.CultureInfo culture)
      {
         throw new System.NotImplementedException();
      }
   }

  

   class BoolToVisibilityConverter : IValueConverter
   {
      #region IValueConverter Members
      /// <summary>
      /// Converts a value.
      /// </summary>
      /// <param name="value">The value produced by the binding source.</param>
      /// <param name="targetType">The type of the binding target property.</param>
      /// <param name="parameter">The converter parameter to use.</param>
      /// <param name="culture">The culture to use in the converter.</param>
      /// <returns>
      /// A converted value. If the method returns null, the valid null value is used.
      /// </returns>
      public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
      {
         if ((bool)value)
         {
            return Visibility.Visible;
         }
         else
         {
            return Visibility.Collapsed;
         }
      }

      /// <summary>
      /// Converts a value.
      /// </summary>
      /// <param name="value">The value that is produced by the binding target.</param>
      /// <param name="targetType">The type to convert to.</param>
      /// <param name="parameter">The converter parameter to use.</param>
      /// <param name="culture">The culture to use in the converter.</param>
      /// <returns>
      /// A converted value. If the method returns null, the valid null value is used.
      /// </returns>
      public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
      {
         var visibility = (Visibility)value;
         if (visibility == Visibility.Visible)
         {
            return true;
         }
         else
         {
            return false;
         }
      }
      #endregion
   }


   [ValueConversion(typeof(bool), typeof(bool))]
   public class InverseBooleanConverter : IValueConverter
   {
      #region IValueConverter Members
      /// <summary>
      /// Converts a value.
      /// </summary>
      /// <param name="value">The value produced by the binding source.</param>
      /// <param name="targetType">The type of the binding target property.</param>
      /// <param name="parameter">The converter parameter to use.</param>
      /// <param name="culture">The culture to use in the converter.</param>
      /// <returns>
      /// A converted value. If the method returns null, the valid null value is used.
      /// </returns>
      public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
      {
         if ((bool)value)
         {
            return Visibility.Collapsed;
         }
         else
         {
            return Visibility.Visible;
         }
      }

      /// <summary>
      /// Converts a value.
      /// </summary>
      /// <param name="value">The value that is produced by the binding target.</param>
      /// <param name="targetType">The type to convert to.</param>
      /// <param name="parameter">The converter parameter to use.</param>
      /// <param name="culture">The culture to use in the converter.</param>
      /// <returns>
      /// A converted value. If the method returns null, the valid null value is used.
      /// </returns>
      public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
      {
         var visibility = (Visibility)value;
         if (visibility == Visibility.Visible)
         {
            return false;
         }
         else
         {
            return true;
         }
      }
      #endregion

   }
}
   

